@@ -1,7 +1,10 @@
 import logging
 from pathlib import Path
 import os
-import tkinter as tk
+try:
+    import tkinter as tk
+except ImportError:
+    print(f'\n\n  Please install --> python3-tk: on Ubuntu sudo apt-get install python3-tk\n\n')
 from tkinter import ttk
 from time import sleep
 from tkinter.filedialog import askdirectory, askopenfilename
